#include<math.h>

static double   fiRe(double tau)
{
  double x;
  if(tau<1)
  { x=asin(sqrt(tau));
    return x*x;
  }else if(tau==1) return 0;
  else
  {
    x=sqrt(1-1/tau);
    x=log((1+x)/(1-x));
    return -0.25*(x*x - M_PI*M_PI);
  }   
}

static double fiIm(double tau)
{
  double x;
  if(tau<=1) return 0;
  else
  {
     x=sqrt(1-1/tau);
     x=log((1+x)/(1-x));
     return 0.5*x*M_PI;
  }
}

static double   giRe(double tau)
{
  double x;
  if(tau<1) return sqrt(1/tau-1)*asin(sqrt(tau));
  else if(tau==1) return 0;
  else
  {
    x=sqrt(1-1/tau);
    x=log((1+x)/(1-x));
    return 0.5*sqrt(1-1/tau)*x;
  }   
}

static double giIm(double tau)
{
  double x;
  if(tau<=1) return 0;
  else
  {
     x=sqrt(1-1/tau);
     return -0.5*x*M_PI;
  }
}


double FevenFr(double z)
{
  double tau= z*z/4;
  return (tau+(tau-1)*fiRe(tau))/(tau*tau);
}

double FevenFi(double z)
{
  double tau= z*z/4;
  return (tau-1)*fiIm(tau)/(tau*tau);
}

double VFrA(double z)
{
  double tau= z*z/4;
  return -(2*tau*tau + 3*tau + 3*(2*tau-1)*fiRe(tau))/(2*tau*tau);
}

double VFiA(double z)
{
  double tau= z*z/4;
  return -(3*(2*tau-1)*fiIm(tau))/(2*tau*tau);
}





double I1evenFr(double z,double w)
{
  double a= 4/(z*z);
  double b= 4/(w*w);
  double x=a*b/(a-b);
  return 0.5*x+0.5*x*x*(fiRe(1/a)-fiRe(1/b))+x*x/b*(giRe(1/a)-giRe(1/b));
}

double I1evenFi(double z,double w)
{
  double a= 4/(z*z);
  double b= 4/(w*w);
  double x=a*b/(a-b);
  return 0.5*x*x*(fiIm(1/a)-fiIm(1/b))+x*x/b*(giIm(1/a)-giIm(1/b));
}


double I2evenFr(double z,double w)
{
  double a= 4/(z*z);
  double b= 4/(w*w);
  double x=a*b/(a-b);
  return -0.5*x*(fiRe(1/a)-fiRe(1/b));
}

double I2evenFi(double z,double w)
{
  double a= 4/(z*z);
  double b= 4/(w*w);
  double x=a*b/(a-b);
  return -0.5*x*(fiIm(1/a)-fiIm(1/b));
}


double Foddr(double z) { double tau=z*z/4; return fiRe(tau)/tau;}
double Foddi(double z) { double tau=z*z/4; return fiIm(tau)/tau;} 

double F0r(double z)   { double tau=z*z/4; return -(tau-fiRe(tau))/(tau*tau);}
double F0i(double z)   { double tau=z*z/4; return fiIm(tau)/(tau*tau);}

double XNF(double Q)
{ if(Q<5) return 4; 
  if(Q<175) return 5;
  return 6;
}
